# UnitsByTests


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**aid** | **str** | Unique ID of the account group owning the test that is generating units | [optional] 
**account_group_name** | **str** | Name of the account group which owns the test that is generating the units | [optional] 
**enterprise_units_used** | **int** | Units generated by the by the enterprise agents running the test | [optional] 
**enterprise_units_projected** | **int** | Enterprise Units projected in the current usage period, based on units consumed to date and configuration of the test | [optional] 
**cloud_units_used** | **int** | Units generated by the by the cloud agents running the test | [optional] 
**cloud_units_projected** | **int** | Cloud Units projected in the current usage period, based on units consumed to date and configuration of the test | [optional] 
**test_id** | **str** | Unique ID of the test generating usage | [optional] 
**test_name** | **str** | Name of the test generating usage | [optional] 
**test_type** | **str** | Type of test generating usage. Note that this is a friendly testType entry (so it shouldn’t be parsed to discover the correct operation to query for configuration details). | [optional] 
**is_instant_test** | **bool** | Indicates whether the test is scheduled or instant | [optional] 

## Example

```python
from thousandeyes_sdk.usage.models.units_by_tests import UnitsByTests

# TODO update the JSON string below
json = "{}"
# create an instance of UnitsByTests from a JSON string
units_by_tests_instance = UnitsByTests.from_json(json)
# print the JSON string representation of the object
print(UnitsByTests.to_json())

# convert the object into a dict
units_by_tests_dict = units_by_tests_instance.to_dict()
# create an instance of UnitsByTests from a dict
units_by_tests_from_dict = UnitsByTests.from_dict(units_by_tests_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


